import React, { FC } from 'react';
import { SubmitHandler, useForm } from 'react-hook-form';
import { Button, Grid, Typography, Link, Hidden } from '@material-ui/core';
import { NonAuthRoutes } from 'api/routes';
import axios from 'axios';
import { InputField } from 'components/Auth/InputField/InputField';
import { registerSenior } from 'api/registerSenior';
import { RegisterSeniorType } from 'types/RegisterSeniorType';
import { signUpFormStyle } from './SignUpForm.style';

export const SignUpForm: FC = () => {
  const { control, errors, handleSubmit } = useForm<RegisterSeniorType>();

  const onSubmit: SubmitHandler<RegisterSeniorType> = (
    values: RegisterSeniorType,
  ) => {
    registerSenior(values);
  };

  const classes = signUpFormStyle();
  return (
    <>
      <header>
        <Grid item container>
          <Grid item xs={12} color="primary" className={classes.paddingTop}>
            <Typography variant="h1">SIGN UP</Typography>
          </Grid>
        </Grid>
      </header>

      <form
        className={classes.form}
        onSubmit={handleSubmit(onSubmit)}
        data-testid="Form"
      >
        <Grid item container>
          <Grid item xs={12} md={5}>
            <InputField
              name="user.firstName"
              type="text"
              control={control}
              rules={{
                maxLength: 150,
                required: {
                  value: true,
                  message: 'Insert valid first name',
                },
              }}
              label="First name"
              error={!!errors.user?.firstName}
              errorMessage="Insert valid first name"
            />
          </Grid>

          <Hidden smDown>
            <Grid item xs={2} />
          </Hidden>

          <Grid item xs={12} md={5}>
            <InputField
              name="user.lastName"
              type="text"
              control={control}
              rules={{
                maxLength: 150,
                required: {
                  value: true,
                  message: 'Insert valid last name',
                },
              }}
              label="Last name"
              error={!!errors.user?.lastName}
              errorMessage="Insert valid last name"
            />
          </Grid>

          <InputField
            name="homeAddress.address"
            type="text"
            control={control}
            rules={{
              required: {
                value: true,
                message: 'Insert valid address',
              },
            }}
            label="Address"
            error={!!errors.homeAddress?.address}
            errorMessage="Insert valid address"
          />

          <Grid item xs={12} md={5}>
            <InputField
              name="phoneNumber"
              type="number"
              control={control}
              rules={{
                maxLength: 15,
                required: {
                  value: true,
                  message: 'Insert valid phone number',
                },
              }}
              label="Phone number"
              error={!!errors.phoneNumber}
              errorMessage="Insert valid phone number"
            />
          </Grid>

          <Hidden smDown>
            <Grid item xs={2} />
          </Hidden>

          <Grid item xs={12} md={5}>
            <InputField
              name="memberCardNumber"
              type="number"
              control={control}
              rules={{
                maxLength: 20,
                required: {
                  value: true,
                  message: 'Insert valid card number',
                },
              }}
              label="Card number"
              error={!!errors.memberCardNumber}
              errorMessage="Insert valid card number"
            />
          </Grid>

          <Grid item xs={12} className={classes.paddingBottomSmall}>
            <InputField
              name="notes"
              type="text"
              control={control}
              rules={{
                required: {
                  value: true,
                  message: 'Add notes',
                },
              }}
              label="Notes"
              error={!!errors.notes}
              errorMessage="Insert notes"
            />
          </Grid>

          <InputField
            name="user.username"
            type="text"
            control={control}
            rules={{
              maxLength: 150,
              required: {
                value: true,
                message: 'Insert valid username',
              },
            }}
            label="Username"
            error={!!errors.user?.username}
            errorMessage="Insert valid username"
          />

          <InputField
            name="user.email"
            type="email"
            control={control}
            rules={{
              validate: (value: string) =>
                /^[A-Z0-9._%+-]+@[A-Z0-9.-]+\.[A-Z]{2,}$/i.test(value),
              required: {
                value: true,
                message: 'Email is not valid',
              },
            }}
            label="Email"
            error={!!errors.user?.email}
            errorMessage="Insert email"
          />

          <InputField
            name="user.password"
            type="password"
            control={control}
            rules={{
              minLength: 8,
              maxLength: 60,
              required: {
                value: true,
                message: 'Insert valid password',
              },
            }}
            label="Password"
            error={!!errors.user?.password}
            errorMessage="Insert valid password"
          />

          <Button
            data-testid="Submit"
            type="submit"
            fullWidth
            variant="contained"
            color="primary"
            className={classes.submit}
          >
            Sign Up
          </Button>
        </Grid>
      </form>

      <Grid item container>
        <Grid item xs={12} color="primary" className={classes.paddingBottom}>
          <Typography>
            Already have an account? &nbsp;
            <Link href={`${NonAuthRoutes.auth}${NonAuthRoutes.signIn}`}>
              Log in.
            </Link>
          </Typography>
        </Grid>
      </Grid>
    </>
  );
};
